aboutsummaryrefslogtreecommitdiff
path: root/src/patch/ghost_zone.cc
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2001-08-06 13:43:20 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2001-08-06 13:43:20 +0000
commit734c4a229deb64d98d4d20e1bd20167a697f6e92 (patch)
tree8fc48bf97731d199e18657de0dcd9354276cc4b3 /src/patch/ghost_zone.cc
parented0b7ba75de5dd7d20c694df99a79535a2f00e8c (diff)
when comparing angles from different patches,
compare them mod 2*pi radians (360 degrees) git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@249 f88db872-0e4f-0410-b76b-b9085cfa78c5
Diffstat (limited to 'src/patch/ghost_zone.cc')
-rw-r--r--src/patch/ghost_zone.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/patch/ghost_zone.cc b/src/patch/ghost_zone.cc
index 2eb8af5..4e06555 100644
--- a/src/patch/ghost_zone.cc
+++ b/src/patch/ghost_zone.cc
@@ -226,13 +226,14 @@ if (! ( (common_coords_set == my_edge().coords_set_perp())
local_coords::name_of_coords_set(other_edge().coords_set_par()));
/*NOTREACHED*/
-// perp coordinate must match across the two patches
-if (fuzzy<fp>::NE(my_edge().grid_outer_perp(), other_edge().grid_outer_perp()))
+// perp coordinate must match (mod 2*pi) across the two patches
+if (! local_coords::fuzzy_EQ_ang( my_edge().grid_outer_perp(),
+ other_edge().grid_outer_perp()))
then error_exit(ERROR_EXIT,
"***** interpatch_ghost_zone::interpatch_ghost_zone:\n"
" my_patch().name()=\"%s\" my_edge().name()=%s\n"
" other_patch().name()=\"%s\" other_edge().name()=%s\n"
-" perp coordinate doesn't match across the two patches!\n"
+" perp coordinate doesn't match (mod 2*pi) across the two patches!\n"
" my_edge().grid_outer_perp()=%g\n"
" other_edge.grid_outer_perp()=%g\n"
,